# scireader
SciReader is a ScispaCy-based natural language processing pipeline for scientific literature mining. To help combat the COVID-19 pandemic, it has been applied to find the most relevant literature given a query research topic.

### Python Dependencies and Requirements:
[spacy: 2.2.1](https://github.com/explosion/spaCy)  
[scispacy: 0.2.4](https://github.com/allenai/scispacy)  
numpy: 1.17.4  
[wmd: 1.3.2](https://github.com/src-d/wmd-relax)  
pandas: 0.25.3  
scikit-learn: 0.21.3  
re: 2.2.1  
json: 2.0.9  


### Recommeded pre-trained ScispaCy model:
[en_core_sci_lg: 0.2.4](https://s3-us-west-2.amazonaws.com/ai2-s2-scispacy/releases/v0.2.4/en_core_sci_lg-0.2.4.tar.gz)　　

### Installation
```
pip install scireader
```
